@@ -13,7 +13,7 @@ sub _croak {
 
 use XSLoader;
 BEGIN {
-    our $VERSION = '2.001001';
+    our $VERSION = '2.001002';
     #$VERSION =~ s/-TRIAL[0-9]*\z//;
     XSLoader::load;
 }
@@ -467,6 +467,8 @@ __END__
 
 =encoding UTF-8
 
+=for highlighter language=perl
+
 =head1 NAME
 
 Function::Parameters - define functions and methods with parameter lists ("subroutine signatures")
@@ -1587,15 +1589,42 @@ Or using C<Function::Parameters> itself:
 
 =back
 
+=begin :README
+
+=head1 INSTALLATION
+
+To download and install this module, use your favorite CPAN client, e.g.
+L<C<cpan>|cpan>:
+
+=for highlighter language=sh
+
+    cpan Function::Parameters
+
+Or L<C<cpanm>|cpanm>:
+
+    cpanm Function::Parameters
+
+To do it manually, run the following commands (after downloading and unpacking
+the tarball):
+
+    perl Makefile.PL
+    make
+    make test
+    make install
+
+=end :README
+
 =head1 SUPPORT AND DOCUMENTATION
 
 After installing, you can find documentation for this module with the
-perldoc command.
+L<C<perldoc>|perldoc> command.
+
+=for highlighter language=sh
 
     perldoc Function::Parameters
 
 You can also look for information at
-L<https://metacpan.org/pod/Function%3A%3AParameters>.
+L<https://metacpan.org/pod/Function::Parameters>.
 
 To see a list of open bugs, visit
 L<https://rt.cpan.org/Public/Dist/Display.html?Name=Function-Parameters>.
@@ -1616,12 +1645,12 @@ Lukas Mai, C<< <l.mai at web.de> >>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010-2014, 2017 Lukas Mai.
+Copyright (C) 2010-2014, 2017 Lukas Mai.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
 by the Free Software Foundation; or the Artistic License.
 
-See http://dev.perl.org/licenses/ for more information.
+See L<http://dev.perl.org/licenses/> for more information.
 
 =cut
